@@ -7,6 +7,7 @@ import yaml
 from compose.config import types
 from compose.config.config import V1
 from compose.config.config import V2_0
+from compose.config.config import V2_1
 
 
 def serialize_config_type(dumper, data):
@@ -18,7 +19,7 @@ yaml.SafeDumper.add_representer(types.VolumeFromSpec, serialize_config_type)
 yaml.SafeDumper.add_representer(types.VolumeSpec, serialize_config_type)
 
 
-def serialize_config(config):
+def denormalize_config(config):
     denormalized_services = [
         denormalize_service_dict(service_dict, config.version)
         for service_dict in config.services
@@ -27,16 +28,26 @@ def serialize_config(config):
         service_dict.pop('name'): service_dict
         for service_dict in denormalized_services
     }
+    networks = config.networks.copy()
+    for net_name, net_conf in networks.items():
+        if 'external_name' in net_conf:
+            del net_conf['external_name']
 
-    output = {
-        'version': V2_0,
+    version = config.version
+    if version not in (V2_0, V2_1):
+        version = V2_1
+
+    return {
+        'version': version,
         'services': services,
-        'networks': config.networks,
+        'networks': networks,
         'volumes': config.volumes,
     }
 
+
+def serialize_config(config):
     return yaml.safe_dump(
-        output,
+        denormalize_config(config),
         default_flow_style=False,
         indent=2,
         width=80)
